==> python2-openstacksdk-0.8.6-1-any.pkg.tar.xz: usr/lib/python2.7/site-packages/openstack/tests/unit/identity/v2/test_extension.py <==
# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.

import datetime

import mock
import testtools

from openstack.identity.v2 import extension

IDENTIFIER = 'IDENTIFIER'
EXAMPLE = {
    'alias': '1',
    'description': '2',
    'links': '3',
    'name': '4',
    'namespace': '5',
    'updated': '2015-03-09T12:14:57.233772',
}


class TestExtension(testtools.TestCase):

    def test_basic(self):
        sot = extension.Extension()
        self.assertEqual('extension', sot.resource_key)
        self.assertEqual('extensions', sot.resources_key)
        self.assertEqual('/extensions', sot.base_path)
        self.assertEqual('identity', sot.service.service_type)
        self.assertFalse(sot.allow_create)
        self.assertFalse(sot.allow_retrieve)
        self.assertFalse(sot.allow_update)
        self.assertFalse(sot.allow_delete)
        self.assertTrue(sot.allow_list)

    def test_make_it(self):
        sot = extension.Extension(EXAMPLE)
        self.assertEqual(EXAMPLE['alias'], sot.alias)
        self.assertEqual(EXAMPLE['description'], sot.description)
        self.assertEqual(EXAMPLE['links'], sot.links)
        self.assertEqual(EXAMPLE['name'], sot.name)
        self.assertEqual(EXAMPLE['namespace'], sot.namespace)
        dt = datetime.datetime(2015, 3, 9, 12, 14, 57, 233772).replace(
            tzinfo=None)
        self.assertEqual(dt, sot.updated_at.replace(tzinfo=None))

    def test_list(self):
        resp = mock.Mock()
        resp.body = {
            "extensions": {
                "values": [
                    {"name": "a"},
                    {"name": "b"},
                ]
            }
        }
        resp.json = mock.Mock(return_value=resp.body)
        session = mock.Mock()
        session.get = mock.Mock(return_value=resp)
        sot = extension.Extension(EXAMPLE)
        result = sot.list(session)
        self.assertEqual(next(result).name, 'a')
        self.assertEqual(next(result).name, 'b')
        self.assertRaises(StopIteration, next, result)

==> python2-openstacksdk-0.12.0-2-any.pkg.tar.xz: usr/lib/python2.7/site-packages/openstack/tests/unit/identity/v2/test_extension.py <==
# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.

import mock
from openstack.tests.unit import base

from openstack.identity.v2 import extension

IDENTIFIER = 'IDENTIFIER'
EXAMPLE = {
    'alias': '1',
    'description': '2',
    'links': '3',
    'name': '4',
    'namespace': '5',
    'updated': '2015-03-09T12:14:57.233772',
}


class TestExtension(base.TestCase):

    def test_basic(self):
        sot = extension.Extension()
        self.assertEqual('extension', sot.resource_key)
        self.assertEqual('extensions', sot.resources_key)
        self.assertEqual('/extensions', sot.base_path)
        self.assertEqual('identity', sot.service.service_type)
        self.assertFalse(sot.allow_create)
        self.assertTrue(sot.allow_get)
        self.assertFalse(sot.allow_update)
        self.assertFalse(sot.allow_delete)
        self.assertTrue(sot.allow_list)

    def test_make_it(self):
        sot = extension.Extension(**EXAMPLE)
        self.assertEqual(EXAMPLE['alias'], sot.alias)
        self.assertEqual(EXAMPLE['description'], sot.description)
        self.assertEqual(EXAMPLE['links'], sot.links)
        self.assertEqual(EXAMPLE['name'], sot.name)
        self.assertEqual(EXAMPLE['namespace'], sot.namespace)
        self.assertEqual(EXAMPLE['updated'], sot.updated_at)

    def test_list(self):
        resp = mock.Mock()
        resp.body = {
            "extensions": {
                "values": [
                    {"name": "a"},
                    {"name": "b"},
                ]
            }
        }
        resp.json = mock.Mock(return_value=resp.body)
        session = mock.Mock()
        session.get = mock.Mock(return_value=resp)
        sot = extension.Extension(**EXAMPLE)
        result = sot.list(session)
        self.assertEqual(next(result).name, 'a')
        self.assertEqual(next(result).name, 'b')
        self.assertRaises(StopIteration, next, result)
